@@ -18,20 +18,19 @@ Default formatting if no options are given.
 List of all possible formatting presets and their values.
 
 	"""
-	VERSION = "0.9.5"
+	VERSION = "0.9.35"
 	"""
 
 Current version of program.
 
 	"""
-	OUTPUT_FORMAT = ".png"
 	def __init__(self):
 		"""
 
 Reads configuration file and 
 
 		"""
-		config = {"version":"0.9.5", "default-preset":"custom1", "image-out":".png", "presets":{"custom1":"%Y%m%d_%H%M%S", "linux1":"%b %d %H:%M:%S"}}
+		config = {"version":"0.9.35", "default-preset":"custom1", "presets":{"custom1":"%Y%m%d_%H%M%S", "linux1":"%b %d %H:%M:%S"}}
 		try:
 			with open("/etc/timediff/timediff.json", "r") as f:
 				config = json.load(f)
@@ -40,5 +39,3 @@ Reads configuration file and
 			sys.exit(1)
 		self.DEFAULT_PRESET = config["default-preset"]
 		self.PRESETS = config["presets"]
-		if config["version"] == "0.9.5":
-			self.OUTPUT_FORMAT = config["image-out"]
